from katka.models import Team
from katka.serializers import TeamSerializer
from katka.viewsets import AuditViewSet


class TeamViewSet(AuditViewSet):
    model = Team
    serializer_class = TeamSerializer
    lookup_field = 'public_identifier'
    lookup_value_regex = '[0-9a-f-]{36}'



from django.contrib.auth.models import Group

from katka.models import Team
from rest_framework import serializers


class TeamSerializer(serializers.ModelSerializer):
    class Meta:
        model = Team
        fields = ('public_identifier', 'name', 'group')

    def to_internal_value(self, data):
        group_name = data.pop('group', None)
        if group_name is not None:
            data['group'] = Group.objects.get(name=group_name).pk

        return super().to_internal_value(data)

    def to_representation(self, instance):
        data = super().to_representation(instance)
        data['group'] = instance.group.name
        return data
